C--------------------------------------------------------------------------
        subroutine ftphis(ounit,histry,status)

C       write a HISTORY record to the FITS header
C
C       ounit   i  fortran output unit number
C       histry  c  input history string
C       OUTPUT PARAMETERS:
C       status  i  output error status (0 = ok)
C
C       written by Wm Pence, HEASARC/GSFC, June 1991

        integer ounit,status
        character*(*) histry
        character*80  rec

        if (status .gt. 0)return
                
        rec='HISTORY   '//histry
        call ftprec(ounit,rec,status)
        end
